@@ -1,5 +1,20 @@
 #pragma once
 
+#ifdef USING_QT
+#include <QtGlobal> // need this to get Q_OS_ANDROID #define, which we need before we include anything else!
+
+#if defined(Q_OS_ANDROID)
+#define DEPLOYMENT_PATH "assets:/"
+#else
+#define DEPLOYMENT_PATH ""
+#endif
+#endif
+
+const int majorVersion = 0;
+const int minorVersion = 25;
+
+extern bool debugwindow;
+
 const int n_epochs_c = 10;
 const int n_players_c = 4;
 const int map_width_c = 5;
