@@ -254,6 +254,7 @@ GameState::GameState() {
 	this->mouse_image = NULL;
 	this->mouse_off_x = 0;
 	this->mouse_off_y = 0;
+	this->confirm_type = CONFIRMTYPE_UNKNOWN;
     this->confirm_window = NULL;
     this->confirm_yes_button = NULL;
     this->confirm_no_button = NULL;
@@ -348,7 +349,8 @@ void ChooseGameTypeGameState::reset() {
 }
 
 void ChooseGameTypeGameState::draw() {
-	screen->clear();
+	//screen->clear();
+	background->draw(0, 0, false);
 
 	this->choosegametypePanel->draw();
 
@@ -395,7 +397,8 @@ void ChooseDifficultyGameState::reset() {
 }
 
 void ChooseDifficultyGameState::draw() {
-	screen->clear();
+	//screen->clear();
+	background->draw(0, 0, false);
 
 	this->choosedifficultyPanel->draw();
 
@@ -416,14 +419,43 @@ void ChooseDifficultyGameState::mouseClick(int m_x,int m_y,bool m_left,bool m_mi
 	this->choosedifficultyPanel->input(m_x, m_y, m_left, m_middle, m_right, click);
 }
 
-ChoosePlayerGameState::ChoosePlayerGameState() {
+ChoosePlayerGameState::ChoosePlayerGameState() : button_red(NULL), button_yellow(NULL), button_green(NULL), button_blue(NULL) {
 }
 
 ChoosePlayerGameState::~ChoosePlayerGameState() {
 }
 
+void ChoosePlayerGameState::reset() {
+	this->screen_page->free(true);
+
+	const int xpos = 64;
+	int ypos = 64;
+	const int ydiff = 48;
+
+	button_red = new Button(xpos, ypos, "CONTROLLER OF THE RED PEOPLE", letters_large);
+	ypos += ydiff;
+	screen_page->add(button_red);
+
+	button_yellow = new Button(xpos, ypos, "CONTROLLER OF THE YELLOW PEOPLE", letters_large);
+	ypos += ydiff;
+	screen_page->add(button_yellow);
+
+	button_green = new Button(xpos, ypos, "CONTROLLER OF THE GREEN PEOPLE", letters_large);
+	ypos += ydiff;
+	screen_page->add(button_green);
+
+	button_blue = new Button(xpos, ypos, "CONTROLLER OF THE BLUE PEOPLE", letters_large);
+	ypos += ydiff;
+	screen_page->add(button_blue);
+}
+
 void ChoosePlayerGameState::draw() {
-	player_select->draw(0, 0, false);
+	//player_select->draw(0, 0, false);
+	//screen->clear();
+	background->draw(0, 0, false);
+    Image::writeMixedCase(160, 16, letters_large, letters_small, NULL, "Select a Player", Image::JUSTIFY_CENTRE, true);
+
+	this->screen_page->draw();
 
 	if( human_player == PLAYER_DEMO )
 		mouse_image = mouse_pointers[0];
@@ -501,13 +533,15 @@ void PlaceMenGameState::reset() {
 }
 
 void PlaceMenGameState::draw() {
-    screen->clear(); // workaround for bug on Symbian where background doesn't show (with 4x gfx)!
+	char buffer[256] = "";
+
+	screen->clear(); // workaround for bug on Symbian where background doesn't show (with 4x gfx)!
 	background_islands->draw(0, 0, false);
 
-    char buffer[256] = "";
-
-    sprintf(buffer, "Gigalomania v%d %d", majorVersion, minorVersion);
-    Image::writeMixedCase(160, 228, letters_large, letters_small, numbers_white, buffer, Image::JUSTIFY_CENTRE, true);
+	if( !using_old_gfx ) {
+		sprintf(buffer, "Gigalomania v%d %d", majorVersion, minorVersion);
+	    Image::writeMixedCase(160, 228, letters_large, letters_small, numbers_white, buffer, Image::JUSTIFY_CENTRE, true);
+	}
 
     /*this->choosemenPanel->draw();
     this->screen_page->draw();
@@ -527,9 +561,18 @@ void PlaceMenGameState::draw() {
 	Image::writeMixedCase(cx, cy, letters_large, letters_small, NULL, buffer, Image::JUSTIFY_CENTRE, true);
     cy += l_h + 2;
 
+	int year = epoch_dates[start_epoch];
+	bool shiny = start_epoch == n_epochs_c-1;
+	Image::writeNumbers(cx+8, cy, shiny ? numbers_largeshiny : numbers_largegrey, abs(year),Image::JUSTIFY_RIGHT, true);
+	Image *era = ( year < 0 ) ? icon_bc :
+		shiny ? icon_ad_shiny : icon_ad;
+	era->draw(cx+8, cy, true);
+    cy += l_h + 2;
+
     if( human_player != PLAYER_DEMO && gameType == GAMETYPE_ALLISLANDS ) {
 		int n_suspended = getNSuspended();
-        if( n_suspended > 0 ) {
+        if( n_suspended > 0 )
+		{
 			sprintf(buffer, "Saved Men %d", n_suspended);
             Image::writeMixedCase(cx, cy, letters_large, letters_small, numbers_white, buffer, Image::JUSTIFY_CENTRE, true);
 		}
@@ -546,7 +589,7 @@ void PlaceMenGameState::draw() {
     cy += s_h + 2;*/
 
 	if( choosemenPanel->getPage() == ChooseMenPanel::STATE_CHOOSEMEN ) {
-		cy = 80;
+		cy = 60;
 		Image::writeMixedCase(200, cy, letters_large, letters_small, NULL, "Click on the icon below", Image::JUSTIFY_CENTRE, true);
 		cy += l_h + 2;
 		Image::writeMixedCase(200, cy, letters_large, letters_small, NULL, "to choose how many men", Image::JUSTIFY_CENTRE, true);
@@ -588,6 +631,21 @@ void PlaceMenGameState::draw() {
 	GameState::draw();
 }
 
+void PlaceMenGameState::requestNewGame() {
+	if( confirm_window != NULL ) {
+		this->closeConfirmWindow();
+	}
+	confirm_window = new PanelPage(120, 120, 64, 32);
+	confirm_type = CONFIRMTYPE_NEWGAME;
+	Button *text_button = new Button(0, 0, "NEW GAME", letters_small);
+	confirm_window->add(text_button);
+	confirm_yes_button = new Button(0, 16, "YES", letters_small);
+	confirm_window->add(confirm_yes_button);
+	confirm_no_button = new Button(32, 16, "NO", letters_small);
+	confirm_window->add(confirm_no_button);
+	this->screen_page->add(confirm_window);
+}
+
 PlayingGameState::PlayingGameState() : GameState() {
 	this->current_sector = NULL;
 	this->flag_frame_step = 0;
@@ -620,9 +678,6 @@ PlayingGameState::PlayingGameState() : GameState() {
 	this->land_panel = NULL;
 	this->pause_button = NULL;
 	this->quit_button = NULL;
-    /*this->confirm_window = NULL;
-	this->confirm_yes_button = NULL;
-    this->confirm_no_button = NULL;*/
 	this->gamePanel = NULL;
 	this->selected_army = NULL;
 	this->map_display = MAPDISPLAY_MAP;
@@ -784,7 +839,7 @@ bool PlayingGameState::readSectors(Map *map) {
 
 #if defined(USING_QT)
     char fullname[4096] = "";
-    sprintf(fullname, ":/%s/%s", maps_dirname, map->getFilename());
+    sprintf(fullname, "%s%s/%s", DEPLOYMENT_PATH, maps_dirname, map->getFilename());
     LOG("open: %s\n", fullname);
     QFile file(fullname);
     if( !file.open(QIODevice::ReadOnly) ) {
@@ -973,6 +1028,7 @@ void PlayingGameState::reset() {
 			map_panels[x][y] = NULL;
 		}
 	}
+	confirm_type = CONFIRMTYPE_UNKNOWN;
 	confirm_window = NULL;
 	confirm_yes_button = NULL;
 	confirm_no_button = NULL;
@@ -1300,10 +1356,10 @@ void PlayingGameState::draw() {
 			if( i == BUILDING_TOWER )
 				flags[ current_sector->getPlayer() ][frame_counter % n_flag_frames_c]->draw(offset_land_x_c + building->getX() + offset_flag_x_c, offset_land_y_c + building->getY() + offset_flag_y_c, true);
 
-			const int health_xpos = offset_land_x_c + building->getX();
+			const int health_xpos = offset_land_x_c + building->getX() + 4;
 			//const int health_ypos = offset_land_y_c + building->getY() - 16;
 			const int health_ypos = offset_land_y_c + building->getY() + images[ current_sector->getBuildingEpoch() ]->getScaledHeight() + 2;
-			const int health_width = 32;
+			const int health_width = 36;
 			const int health_height = 4;
 			/*float health = (health_width-2) * ((float)building->getHealth()) / (float)building->getMaxHealth();
 			screen->fillRectWithAlpha(scale_width*health_xpos, scale_height*health_ypos, scale_width*health_width, scale_height*health_height, 255, 255, 255, 127);
@@ -1349,8 +1405,10 @@ void PlayingGameState::draw() {
 		Soldier *soldier = soldier_list[i];
 		ASSERT(soldier->epoch != nuclear_epoch_c);
 		if( !isAirUnit(soldier->epoch) ) {
-			int frame = soldier->dir * 4 + ( frame_counter % 3 );
-			Image *image = attackers_walking[soldier->player][soldier->epoch][frame];
+			//int frame = soldier->dir * 4 + ( frame_counter % 3 );
+			//Image *image = attackers_walking[soldier->player][soldier->epoch][frame];
+			int n_frames = n_attacker_frames[soldier->epoch][soldier->dir];
+			Image *image = attackers_walking[soldier->player][soldier->epoch][soldier->dir][frame_counter % n_frames];
 			image->draw(offset_land_x_c + soldier->xpos, offset_land_y_c + soldier->ypos, true);
 		}
 	}
@@ -1673,16 +1731,6 @@ void PlayingGameState::update() {
 			}
 		}
 	}
-
-	/*if( smokeParticleSystem != NULL ) {
-		smokeParticleSystem->update();
-	}
-	if( smokeParticleSystem_busy != NULL ) {
-		smokeParticleSystem_busy->update();
-	}*/
-	/*if( current_sector->getParticleSystem() != NULL ) {
-		current_sector->getParticleSystem()->update();
-	}*/
 }
 
 bool PlayingGameState::buildingMouseClick(int s_m_x,int s_m_y,bool m_left,bool m_right,Building *building) {
@@ -1777,7 +1825,7 @@ void ChoosePlayerGameState::mouseClick(int m_x,int m_y,bool m_left,bool m_middle
 	GameState::mouseClick(m_x, m_y, m_left, m_middle, m_right, click);
 
 	//bool m_left = mouse_left(m_b);
-	int s_m_y = (int)(m_y / scale_height);
+	/*int s_m_y = (int)(m_y / scale_height);
 	if( m_left && click ) {
 		human_player = -1;
 		if( s_m_y >= 55 && s_m_y < 99 )
@@ -1795,6 +1843,27 @@ void ChoosePlayerGameState::mouseClick(int m_x,int m_y,bool m_left,bool m_middle
 			newGame();
 			//::gamestate->fadeScreen(false, 0, NULL); // n.b., must be "gamestate" not "this", to refer to the new gamestate!
 		}
+	}*/
+	int player = -1;
+    if( m_left && click && button_red->mouseOver(m_x, m_y) ) {
+		player = 0;
+	}
+    else if( m_left && click && button_yellow->mouseOver(m_x, m_y) ) {
+		player = 2;
+	}
+    else if( m_left && click && button_green->mouseOver(m_x, m_y) ) {
+		player = 1;
+	}
+    else if( m_left && click && button_blue->mouseOver(m_x, m_y) ) {
+		player = 3;
+	}
+
+	if( player != -1 ) {
+		human_player = player;
+		//human_player = PLAYER_DEMO; // force demo mode
+		setGameStateID(GAMESTATEID_PLACEMEN);
+		newGame();
+		//::gamestate->fadeScreen(false, 0, NULL); // n.b., must be "gamestate" not "this", to refer to the new gamestate!
 	}
 }
 
@@ -1813,7 +1882,15 @@ void PlaceMenGameState::mouseClick(int m_x,int m_y,bool m_left,bool m_middle,boo
         registerClick();
         ASSERT( confirm_window != NULL );
         this->closeConfirmWindow();
-        application->setQuit();
+		if( confirm_type == CONFIRMTYPE_NEWGAME ) {
+			newGame();
+		}
+		else if( confirm_type == CONFIRMTYPE_QUITGAME ) {
+	        application->setQuit();
+		}
+		else {
+			T_ASSERT(false);
+		}
     }
     else if( !done && m_left && click && confirm_no_button != NULL && confirm_no_button->mouseOver(m_x, m_y) ) {
         LOG("confirm no clicked\n");
@@ -2024,6 +2101,7 @@ void PlayingGameState::cancelPlayerAskingAlliance() {
 //void PlayingGameState::requestQuit() {
 void GameState::requestQuit() {
     if( confirm_window == NULL /*&& gameResult != GAMERESULT_QUIT*/ && fade == NULL ) {
+		confirm_type = CONFIRMTYPE_QUITGAME;
 		confirm_window = new PanelPage(120, 120, 64, 32);
 		Button *text_button = new Button(0, 0, "REALLY QUIT", letters_small);
 		confirm_window->add(text_button);
@@ -2357,8 +2435,10 @@ bool PlayingGameState::validSoldierLocation(int epoch,int xpos,int ypos) {
 	if( epoch == 6 || epoch == 7 || epoch == 9 )
 		return true;
 
-	int size_x = attackers_walking[0][ epoch ][0]->getScaledWidth();
-	int size_y = attackers_walking[0][ epoch ][0]->getScaledHeight();
+	//int size_x = attackers_walking[0][ epoch ][0]->getScaledWidth();
+	//int size_y = attackers_walking[0][ epoch ][0]->getScaledHeight();
+	int size_x = attackers_walking[0][ epoch ][0][0]->getScaledWidth();
+	int size_y = attackers_walking[0][ epoch ][0][0]->getScaledHeight();
 	if( xpos < 0 || xpos + size_x >= land_width_c || ypos < 0 || ypos + size_y >= land_height_c )
 		okay = false;
 	else if( current_sector->getPlayer() != -1 ) {
