@@ -9,10 +9,15 @@ using std::string;
 //#include "game.h"
 #include "common.h"
 
-class Image;
-class ImageButton;
-class Button;
-class PanelPage;
+namespace Gigalomania {
+	class Image;
+	class ImageButton;
+	class Button;
+	class PanelPage;
+}
+
+using namespace Gigalomania;
+
 class ChooseGameTypePanel;
 class ChooseDifficultyPanel;
 class ChooseMenPanel;
@@ -170,6 +175,12 @@ protected:
 	bool mobile_ui_display_mouse; // if mobile_ui is true, should we display the mouse icon?
 	Image *mouse_image;
 	int mouse_off_x, mouse_off_y;
+	enum ConfirmType {
+		CONFIRMTYPE_UNKNOWN = -1,
+		CONFIRMTYPE_NEWGAME = 0,
+		CONFIRMTYPE_QUITGAME = 1
+	};
+	ConfirmType confirm_type;
     PanelPage *confirm_window;
     Button *confirm_yes_button;
     Button *confirm_no_button;
@@ -227,10 +238,15 @@ public:
 };
 
 class ChoosePlayerGameState : public GameState {
+	Button *button_red;
+	Button *button_yellow;
+	Button *button_green;
+	Button *button_blue;
 public:
 	ChoosePlayerGameState();
 	virtual ~ChoosePlayerGameState();
 
+	virtual void reset();
 	virtual void draw();
 	virtual void mouseClick(int m_x,int m_y,bool m_left,bool m_middle,bool m_right,bool click);
 };
@@ -261,6 +277,7 @@ public:
 	int getStartMapY() const {
 		return this->start_map_y;
 	}
+	void requestNewGame();
 };
 
 class PlayingGameState : public GameState {
