@@ -53,6 +53,8 @@ inline void CreateMask( Uint32& rmask, Uint32& gmask, Uint32& bmask, Uint32& ama
 extern const bool DEBUG;
 extern const int DEBUGLEVEL;
 
+using namespace Gigalomania;
+
 SDL_Surface *Image::dest_surf = NULL;
 
 Image::Image() {
@@ -346,13 +348,17 @@ bool Image::createAlphaForColor(bool mask, unsigned char mr, unsigned char mg, u
 
 	this->convertToHiColor(true);
 
+#ifdef TIMING
+	int time_s = clock();
+#endif
+
 	SDL_LockSurface(this->surface);
-	for(int cx=0;cx<w;cx++) {
-		for(int cy=0;cy<h;cy++) {
+	// faster to read in x direction! (caching?)
+	for(int cy=0;cy<h;cy++) {
+		for(int cx=0;cx<w;cx++) {
 			Uint32 pixel = getpixel(this->surface, cx, cy);
 			Uint8 r = 0, g = 0, b = 0, a = 0;
 			SDL_GetRGB(pixel, this->surface->format, &r, &g, &b);
-			a = 255;
 			if( r == ar && g == ag && b == ab ) {
 				r = 0;
 				g = 0;
@@ -361,7 +367,6 @@ bool Image::createAlphaForColor(bool mask, unsigned char mr, unsigned char mg, u
 				pixel = SDL_MapRGBA(this->surface->format, r, g, b, a);
 				putpixel(this->surface, cx, cy, pixel);
 			}
-			//else if( mask && r == this->mask_r && g == this->mask_g && b == mask_b ) {
 			else if( mask && r == mr && g == mg && b == mb ) {
 				r = 0;
 				g = 0;
@@ -374,6 +379,13 @@ bool Image::createAlphaForColor(bool mask, unsigned char mr, unsigned char mg, u
 	}
 
 	SDL_UnlockSurface(this->surface);
+#ifdef TIMING
+	int time_taken = clock() - time_s;
+	LOG("    image createAlphaForColor time %d\n", time_taken);
+	static int total = 0;
+	total += time_taken;
+	LOG("    image createAlphaForColor total %d\n", total);
+#endif
 	return true;
 }
 
@@ -382,20 +394,33 @@ void Image::scaleAlpha(float scale) {
 	if( bpp != 32 )
 		return;
 
+#ifdef TIMING
+	int time_s = clock();
+#endif
+
 	int w = this->getWidth();
 	int h = this->getHeight();
 	SDL_LockSurface(this->surface);
-	for(int cx=0;cx<w;cx++) {
-		for(int cy=0;cy<h;cy++) {
+	// faster to read in x direction! (caching?)
+	for(int cy=0;cy<h;cy++) {
+		for(int cx=0;cx<w;cx++) {
 			Uint32 pixel = getpixel(this->surface, cx, cy);
 			Uint8 r = 0, g = 0, b = 0, a = 0;
 			SDL_GetRGBA(pixel, this->surface->format, &r, &g, &b, &a);
-			a *= scale;
+			//a *= scale;
+			a = (Uint8)(a*scale);
 			pixel = SDL_MapRGBA(this->surface->format, r, g, b, a);
 			putpixel(this->surface, cx, cy, pixel);
 		}
 	}
 	SDL_UnlockSurface(this->surface);
+#ifdef TIMING
+	int time_taken = clock() - time_s;
+	LOG("    image scaleAlpha time %d\n", time_taken);
+	static int total = 0;
+	total += time_taken;
+	LOG("    image scaleAlpha total %d\n", total);
+#endif
 }
 
 bool Image::convertToHiColor(bool alpha) {
@@ -543,82 +568,96 @@ bool Image::copyPalette(const Image *image) {
 	return true;
 }
 
-// side-effect: also converts images with < 256 colours to have 256 colours
+// side-effect: also converts images with < 256 colours to have 256 colours, unless scaling is 1.0
 void Image::scale(float sx,float sy) {
-	// only supported for reducing the size - this is all we need, and is easier to optimise for performance
-	ASSERT( sx <= 1.0f );
-	ASSERT( sy <= 1.0f );
+	if( sx == 1.0f && sy == 1.0f ) {
+		return;
+	}
+	// only supported for either reducing or englarging the size - this is all we need, and is easier to optimise for performance
+	bool enlarging = false;
+	if( sx > 1.0f || sy > 1.0f ) {
+		// making larger
+		ASSERT( sx > 1.0f );
+		ASSERT( sy > 1.0f );
+		enlarging = true;
+	}
 #ifdef TIMING
 	int time_s = clock();
 #endif
-	//this->scale_x *= sx;
-	//this->scale_y *= sy;
 	int w = this->getWidth();
 	int h = this->getHeight();
 	SDL_LockSurface(this->surface);
 	unsigned char *src_data = (unsigned char *)this->surface->pixels;
-	/*FIBITMAP *new_bitmap = FreeImage_Allocate(sx * w, sy*h, this->surface->format->BitsPerPixel);
-	unsigned char *data = (unsigned char *)FreeImage_GetBits(new_bitmap);*/
 	int bytesperpixel = this->surface->format->BytesPerPixel;
 	int new_width = (int)(w * sx);
 	int new_height = (int)(h * sy);
 	int new_size = (int)(new_width * new_height * bytesperpixel);
 	bool is_paletted = this->isPaletted();
-	//is_paletted = true; // smooth scaling disabled for now, problems with mask colour!
 	unsigned char *new_data = NULL;
-	//float *new_data_nonpaletted = NULL;
 	int *new_data_nonpaletted = NULL;
 	int *count = NULL;
-	if( is_paletted ) {
+	if( is_paletted || enlarging ) {
 		new_data = new unsigned char[new_size];
 	}
 	else {
 		new_data_nonpaletted = new int[new_size];
 		count = new int[new_size];
 		for(int i=0;i<new_size;i++) {
-			//new_data_nonpaletted[i] = 0.0f;
 			new_data_nonpaletted[i] = 0;
 			count[i] = 0;
 		}
 	}
 	// faster to read in x direction! (caching?)
-	for(int cy=0;cy<h;cy++) {
-		int src_indx = cy * this->surface->pitch;
-		for(int cx=0;cx<w;cx++) {
-			//int src_indx = cy * this->surface->pitch + cx * bytesperpixel;
-			for(int i=0;i<bytesperpixel;i++, src_indx++) {
-				//int src_indx = cy * this->surface->pitch + cx * bytesperpixel + i;
-				T_ASSERT(src_indx >= 0 && src_indx < this->surface->pitch*h );
-				unsigned char pt = src_data[ src_indx ];
-				/*for(int x=0;x<sx;x++) {
+	if( enlarging ) {
+		for(int cy=0;cy<h;cy++) {
+			int src_indx = cy * this->surface->pitch;
+			for(int cx=0;cx<w;cx++) {
+				for(int i=0;i<bytesperpixel;i++, src_indx++) {
+					T_ASSERT(src_indx >= 0 && src_indx < this->surface->pitch*h );
+					unsigned char pt = src_data[ src_indx ];
 					for(int y=0;y<sy;y++) {
-						int dx = (int)(cx * sx + x);
-						int dy = (int)(cy * sy + y);*/
-				{
-					{
-						int dx = (int)(cx * sx);
-						int dy = (int)(cy * sy);
-						if( dx >= new_width || dy >= new_height ) {
-							// ignore leftover part
-							continue;
-						}
-						T_ASSERT( dx >= 0 && dx < new_width );
-						T_ASSERT( dy >= 0 && dy < new_height );
-						int dst_indx = (int)(dy * new_width * bytesperpixel + dx * bytesperpixel + i);
-						T_ASSERT(dst_indx >= 0 && dst_indx < new_width*new_height*bytesperpixel );
-						//new_data[ dy * w * sx /* * bytesperpixel + dx * bytesperpixel + i*/ ] = 0;
-						if( is_paletted )
+						for(int x=0;x<sx;x++) {
+							int dx = (int)(cx * sx + x);
+							int dy = (int)(cy * sy + y);
+							T_ASSERT( dx >= 0 && dx < new_width );
+							T_ASSERT( dy >= 0 && dy < new_height );
+							int dst_indx = (int)(dy * new_width * bytesperpixel + dx * bytesperpixel + i);
+							T_ASSERT(dst_indx >= 0 && dst_indx < new_width*new_height*bytesperpixel );
 							new_data[ dst_indx ] = pt;
-						else {
-							//new_data_nonpaletted[ dst_indx ] += (float)pt;
-							new_data_nonpaletted[ dst_indx ] += pt;
-							count[ dst_indx ]++;
 						}
 					}
 				}
 			}
 		}
 	}
+	else {
+		for(int cy=0;cy<h;cy++) {
+			int src_indx = cy * this->surface->pitch;
+			for(int cx=0;cx<w;cx++) {
+				for(int i=0;i<bytesperpixel;i++, src_indx++) {
+					T_ASSERT(src_indx >= 0 && src_indx < this->surface->pitch*h );
+					unsigned char pt = src_data[ src_indx ];
+
+					int dx = (int)(cx * sx);
+					int dy = (int)(cy * sy);
+					if( dx >= new_width || dy >= new_height ) {
+						// ignore leftover part
+						continue;
+					}
+					T_ASSERT( dx >= 0 && dx < new_width );
+					T_ASSERT( dy >= 0 && dy < new_height );
+					int dst_indx = (int)(dy * new_width * bytesperpixel + dx * bytesperpixel + i);
+					T_ASSERT(dst_indx >= 0 && dst_indx < new_width*new_height*bytesperpixel );
+					if( is_paletted )
+						new_data[ dst_indx ] = pt;
+					else {
+						new_data_nonpaletted[ dst_indx ] += pt;
+						count[ dst_indx ]++;
+					}
+				}
+			}
+		}
+	}
 	SDL_UnlockSurface(this->surface);
 
 	{
@@ -626,12 +665,7 @@ void Image::scale(float sx,float sy) {
 		h *= sy;*/
 		w = (int)(w * sx);
 		h = (int)(h * sy);
-		//int w = FreeImage_GetWidth(new_bitmap);
-		//int h = FreeImage_GetHeight(new_bitmap);
-		//int bpp = FreeImage_GetBPP(new_bitmap);
 		int bpp = this->surface->format->BitsPerPixel;
-		//unsigned char *data = (unsigned char *)FreeImage_GetBits(new_bitmap);
-		//int pitch = FreeImage_GetPitch(new_bitmap);
 		int pitch = this->surface->format->BytesPerPixel * w;
 
 		/*Uint32 rmask, gmask, bmask;
@@ -648,7 +682,7 @@ void Image::scale(float sx,float sy) {
 		Uint32 gmask = this->surface->format->Gmask;
 		Uint32 bmask = this->surface->format->Bmask;
 		Uint32 amask = this->surface->format->Amask;
-		if( !is_paletted ) {
+		if( !(is_paletted || enlarging) ) {
 			new_data = new unsigned char[new_size];
 			for(int i=0;i<new_size;i++) {
 				new_data[i] = (unsigned char)(new_data_nonpaletted[i] / count[i]);
@@ -726,20 +760,29 @@ void Image::remap(unsigned char sr,unsigned char sg,unsigned char sb,unsigned ch
 	if( this->surface->format->BitsPerPixel != 24 && this->surface->format->BitsPerPixel != 32 ) {
 		return;
 	}
+	if( rr == sr && rg == sg && rb == sb ) {
+		return;
+	}
+#ifdef TIMING
+	int time_s = clock();
+#endif
 	SDL_LockSurface(this->surface);
 	int w = getWidth();
 	int h = getHeight();
 	int bytesperpixel = this->surface->format->BytesPerPixel;
 	int pitch = this->surface->pitch;
-	for(int x=0;x<w;x++) {
-		for(int y=0;y<h;y++) {
-			/*unsigned char *src_data = (unsigned char *)this->surface->pixels;
-			unsigned char *ptr = &src_data[ y * pitch + x * bytesperpixel ];
-			if( ptr[0] == sr && ptr[1] == sg && ptr[2] == sb ) {
-				ptr[0] = rr;
-				ptr[1] = rg;
-				ptr[2] = rb;
-			}*/
+	/*int isr = (int)sr;
+	int isg = (int)sg;
+	int isb = (int)sb;
+	int mag_s = (int)sqrt( (float)(isr*isr + isg*isg + isb*isb) ); // *255
+	const int threshold = 0.9f * mag_s; // *255
+	int irr = (int)rr;
+	int irg = (int)rg;
+	int irb = (int)rb;
+	int mag_r = (int)sqrt( (float)(irr*irr + irg*irg + irb*irb) ); // *255*/
+	// faster to read in x direction! (caching?)
+	for(int y=0;y<h;y++) {
+		for(int x=0;x<w;x++) {
 			Uint32 pixel = getpixel(this->surface, x, y);
 			Uint8 r = 0, g = 0, b = 0, a = 0;
 			SDL_GetRGBA(pixel, this->surface->format, &r, &g, &b, &a);
@@ -747,10 +790,35 @@ void Image::remap(unsigned char sr,unsigned char sg,unsigned char sb,unsigned ch
 				pixel = SDL_MapRGBA(surface->format, rr, rg, rb, a);
 				putpixel(this->surface, x, y, pixel);
 			}
+			/*if( r == 0 && g == 0 && b == 0 ) {
+				continue;
+			}
+			int ir = (int)r;
+			int ig = (int)g;
+			int ib = (int)b;
+			int mag = (int)sqrt( (float)(ir*ir + ig*ig + ib*ib) ); // *255
+			int dot = ( sr*ir + sg*ig + sb*ib ); // *255*255
+			if( dot >= threshold*mag ) {
+				float cos_angle = ((float)dot) / (float)( mag_s * mag ); // *1
+				int proj_mag = mag * cos_angle; // *255
+				ir = proj_mag * rr / mag_r;
+				ig = proj_mag * rg / mag_r;
+				ib = proj_mag * rb / mag_r;
+				pixel = SDL_MapRGBA(surface->format, ir, ig, ib, a);
+				putpixel(this->surface, x, y, pixel);
+			}*/
 		}
 	}
 
 	SDL_UnlockSurface(this->surface);
+
+#ifdef TIMING
+	int time_taken = clock() - time_s;
+	LOG("    image remap time %d\n", time_taken);
+	static int total = 0;
+	total += time_taken;
+	LOG("    image remap total %d\n", total);
+#endif
 }
 
 //Image *Image::copy(int x,int y,int w,int h) {
@@ -790,28 +858,9 @@ void Image::reshadeRGB(int from, bool to_r, bool to_g, bool to_b) {
 	int h = getHeight();
 	int bytesperpixel = this->surface->format->BytesPerPixel;
 	int pitch = this->surface->pitch;
-	for(int x=0;x<w;x++) {
-		for(int y=0;y<h;y++) {
-			/*unsigned char *src_data = (unsigned char *)this->surface->pixels;
-			unsigned char *ptr = &src_data[ y * pitch + x * bytesperpixel ];
-			int val = ptr[from];
-			int t_diff = 0;
-			int n = 0;
-			for(int j=0;j<3;j++) {
-				if( to[j] && j != from ) {
-					int val2 = ptr[j];
-					int diff = val2 - val;
-					t_diff += diff;
-					n++;
-					ptr[j] = val;
-				}
-			}
-			if( n > 0 && !to[from] ) {
-				t_diff /= n;
-				val += t_diff;
-				ASSERT(val >=0 && val < 256);
-				ptr[from] = val;
-			}*/
+	// faster to read in x direction! (caching?)
+	for(int y=0;y<h;y++) {
+		for(int x=0;x<w;x++) {
 			Uint32 pixel = getpixel(this->surface, x, y);
 			Uint8 rgba[] = {0, 0, 0, 0};
 			SDL_GetRGBA(pixel, this->surface->format, &rgba[0], &rgba[1], &rgba[2], &rgba[3]);
@@ -842,34 +891,21 @@ void Image::reshadeRGB(int from, bool to_r, bool to_g, bool to_b) {
 }
 
 void Image::brighten(float sr, float sg, float sb) {
-#ifdef TIMING
-	int time_s = clock();
-#endif
 	if( this->surface->format->BitsPerPixel != 24 && this->surface->format->BitsPerPixel != 32 ) {
 		return;
 	}
+#ifdef TIMING
+	int time_s = clock();
+#endif
 	float scale[3] = {sr, sg, sb};
 	SDL_LockSurface(this->surface);
 	int w = getWidth();
 	int h = getHeight();
 	int bytesperpixel = this->surface->format->BytesPerPixel;
 	int pitch = this->surface->pitch;
-	for(int x=0;x<w;x++) {
-		for(int y=0;y<h;y++) {
-			/*unsigned char *src_data = (unsigned char *)this->surface->pixels;
-			unsigned char *ptr = &src_data[ y * pitch + x * bytesperpixel ];
-			if( mask && ptr[0] == maskcol.r && ptr[1] == maskcol.g && ptr[2] == maskcol.b ) {
-				continue;
-			}
-			for(int j=0;j<3;j++) {
-				float col = (float)ptr[j];
-				col *= scale[j];
-				if( col < 0 )
-					col = 0;
-				else if( col > 255 )
-					col = 255;
-				ptr[j] = (unsigned char)col;
-			}*/
+	// faster to read in x direction! (caching?)
+	for(int y=0;y<h;y++) {
+		for(int x=0;x<w;x++) {
 			Uint32 pixel = getpixel(this->surface, x, y);
 			Uint8 rgba[] = {0, 0, 0, 0};
 			SDL_GetRGBA(pixel, this->surface->format, &rgba[0], &rgba[1], &rgba[2], &rgba[3]);
@@ -967,12 +1003,6 @@ Image *Image::copy(int x, int y, int w, int h) const {
 	w = (int)(w * scale_x);
 	h = (int)(h * scale_y);
 
-	/*Image *copy_image = createBlankImage(w,h,this->surface->format->BitsPerPixel);
-	copy_image->surface->format->Rmask = this->surface->format->Rmask;
-	copy_image->surface->format->Gmask = this->surface->format->Gmask;
-	copy_image->surface->format->Bmask = this->surface->format->Bmask;
-	copy_image->surface->format->Amask = this->surface->format->Amask;*/
-
 	Image *copy_image = NULL;
 	{
 		SDL_Surface *surface = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h, this->surface->format->BitsPerPixel, this->surface->format->Rmask, this->surface->format->Gmask, this->surface->format->Bmask, this->surface->format->Amask);
@@ -986,8 +1016,9 @@ Image *Image::copy(int x, int y, int w, int h) const {
 	unsigned char *dst_data = (unsigned char *)copy_image->surface->pixels;
 	SDL_LockSurface(this->surface);
 	int bytesperpixel = this->surface->format->BytesPerPixel;
-	for(int cx=0;cx<w;cx++) {
-		for(int cy=0;cy<h;cy++) {
+	// faster to read in x direction! (caching?)
+	for(int cy=0;cy<h;cy++) {
+		for(int cx=0;cx<w;cx++) {
 			for(int i=0;i<bytesperpixel;i++) {
 				int src_indx = ( y + cy ) * this->surface->pitch + ( x + cx ) * bytesperpixel + i;
 				int dst_indx = cy * copy_image->surface->pitch + cx * bytesperpixel + i;
@@ -1378,7 +1409,6 @@ void Image::writeMixedCase(int x,int y,Image *large[26],Image *little[26],Image
 	int n_lines = 0;
 	int max_wid = 0;
 	textLines(&n_lines, &max_wid, text);
-	ASSERT(n_lines == 1 || justify == JUSTIFY_LEFT);
 	int w = little[0]->getScaledWidth();
 	int n_h = 0;
 	if( numbers != NULL )
@@ -1422,3 +1452,47 @@ void Image::writeMixedCase(int x,int y,Image *large[26],Image *little[26],Image
 		cx += w;
 	}
 }
+
+void Image::smooth() {
+	if( this->surface->format->BitsPerPixel != 24 && this->surface->format->BitsPerPixel != 32 ) {
+		return;
+	}
+	int w = getWidth();
+	int h = getHeight();
+	unsigned char *src_data = (unsigned char *)this->surface->pixels;
+	int bytesperpixel = this->surface->format->BytesPerPixel;
+	int pitch = this->surface->pitch;
+	unsigned char *new_data = new unsigned char[w * h * bytesperpixel];
+
+	SDL_LockSurface(this->surface);
+	for(int y=0;y<h;y++) {
+		for(int x=0;x<w;x++) {
+			for(int i=0;i<bytesperpixel;i++) {
+				Uint32 col = 0;
+				if(	x > 0 && x < w-1 && y > 0 && y < h-1 ) {
+						Uint32 sq[9];
+						int indx = 0;
+						for(int sx=x-1;sx<=x+1;sx++) {
+							for(int sy=y-1;sy<=y+1;sy++) {
+								sq[indx++] = src_data[ sy * pitch + sx * bytesperpixel + i ];
+							}
+						}
+						col = ( sq[0] + 2 * sq[1] + sq[2] + 2 * sq[3] + 4 * sq[4] + 2 * sq[5] + sq[6] + 2 * sq[7] + sq[8] ) / 16;
+						//col = ( sq[1] + sq[3] + sq[5] + sq[7] + 12 * sq[4] ) / 16;
+				}
+				else
+					col = src_data[ y * pitch + x * bytesperpixel + i ];
+				new_data[ y * w * bytesperpixel + x * bytesperpixel + i] = (unsigned char)col;
+			}
+		}
+	}
+	for(int y=0;y<h;y++) {
+		for(int x=0;x<w;x++) {
+			for(int i=0;i<bytesperpixel;i++) {
+				src_data[ y * pitch + x * bytesperpixel + i ] = new_data[ y * w * bytesperpixel + x * bytesperpixel + i];
+			}
+		}
+	}
+	delete [] new_data;
+	SDL_UnlockSurface(this->surface);
+}
