@@ -6,14 +6,6 @@
 #include <cstdlib> // n.b., needed on Linux at least
 #include <cstdarg> // n.b., needed on Linux at least
 
-#include "game.h"
-
-#ifdef USING_QT
-#include "qt_screen.h"
-#else
-#include "screen.h"
-#endif
-
 #ifdef _WIN32
 #include <shlobj.h>
 #include <Shlwapi.h>
@@ -26,11 +18,18 @@
 #include <sys/stat.h> // for mkdir
 #endif
 
+#ifdef USING_QT
+#include <QString>
+#include <QDir>
+#include <QDesktopServices>
+#endif
+
 #include <cassert>
 #include <cmath> // n.b., needed on Linux at least
 
 #include "utils.h"
-#include "game.h"
+#include "common.h"
+
 //---------------------------------------------------------------------------
 
 //const bool DEBUG = true;
@@ -352,6 +351,8 @@ void initLogFile() {
 	LOG("Platform: Linux\n");
 #elif defined(__APPLE__) && defined(__MACH__)
 	LOG("Platform: MacOS X\n");
+#elif AROS
+    LOG("Platform: AROS\n");
 #elif defined(Q_OS_SYMBIAN)
     LOG("Platform: Symbian\n");
 #else
@@ -493,3 +494,29 @@ float perlin_noise2(float vec[2]) {
 
 	return lerp(sy, a, b);
 }
+
+#ifdef AROS
+
+#include <proto/intuition.h>
+
+// This needs to be a separate function in a separate file, to avoid name collision with AROS/AmigaOS types Screen and Image.
+// This also means we shouldn't do "using namespace Gigalomania" in utils.cpp, unless we move this function to its own file.
+
+void getAROSScreenSize(int *user_width, int *user_height) {
+	// see http://wiki.amigaos.net/index.php/Intuition_Screens
+	// setup a default in case we can't access the Workbench Screen for some reason
+	*user_width = 640;
+	*user_height = 480;
+	struct Screen *my_wbscreen_ptr = LockPubScreen("Workbench");
+	if( my_wbscreen_ptr == NULL ) {
+		LOG("AROS: failed to lock Workbenc screen\n");
+	}
+	else {
+		*user_width = my_wbscreen_ptr->Width;
+		*user_height = my_wbscreen_ptr->Height;
+		LOG("AROS: Workbench screen is is %d x %d\n", *user_width, *user_height);
+		UnlockPubScreen(NULL, my_wbscreen_ptr);
+	}
+}
+
+#endif
